/// Josh's Logger
/// A Redacted Software Product
/// Developed & Maintained by Josh O'Leary
/// This work is dedicated to the public domain.


#pragma once

#include <format>
#include <string>
#include <iostream>
#include <chrono>
#include <Event.h>
#include <fstream>

namespace jlog
{
    enum class severity
    {
        none,
        verbose,
        debug,
        warning,
        error,
        fatal
    };

    struct LogEntry
    {
        severity level;
        std::string content;
        std::string timestamp;
    };



    static Event<LogEntry> on_log = Event<LogEntry>();

    std::vector<LogEntry> log_history;

    struct token
    {
        std::string colorCode = "";
        std::string content = "";
        std::string delimiter = "[]";
    };

    void log(std::vector<token> tokens);

    void direct (const std::string& message);
    void info   (const std::string& message);
    void verbose(const std::string& message);

    void debug  (const std::string& message);

    void warning(const std::string& message);

    void error  (const std::string& message);

    void fatal  (const std::string& message);

}